@@ -741,12 +741,12 @@ class MmapTests(unittest.TestCase):
 
     def test_repr(self):
         open_mmap_repr_pat = re.compile(
-            r"<fmmap.mmap closed=False, "
+            r"<f?mmap.mmap closed=False, "
             r"access=(?P<access>\S+), "
             r"length=(?P<length>\d+), "
             r"pos=(?P<pos>\d+), "
             r"offset=(?P<offset>\d+)>")
-        closed_mmap_repr_pat = re.compile(r"<fmmap.mmap closed=True>")
+        closed_mmap_repr_pat = re.compile(r"<f?mmap.mmap closed=True>")
         mapsizes = (50, 100, 1000, 1000000, 10000000)
         offsets = tuple((mapsize // 2 // mmap.ALLOCATIONGRANULARITY)
                         * mmap.ALLOCATIONGRANULARITY for mapsize in mapsizes)
@@ -767,7 +767,7 @@ class MmapTests(unittest.TestCase):
                                    offset=offset) as mm:
                         mm.seek(pos)
                         match = open_mmap_repr_pat.match(repr(mm))
-                        self.assertIsNotNone(match)
+                        self.assertIsNotNone(match, repr(mm))
                         self.assertEqual(match.group('access'), access)
                         self.assertEqual(match.group('length'), str(length))
                         self.assertEqual(match.group('pos'), str(pos))
